
import logging
logger = logging.getLogger(__name__)

from agent.models.db.sys import SysOrgan,SysUserRoleOrgan
from datetime import datetime

class SysOrganBusiness:
    def __init__(self, db):
        self.db = db

    def insert_data(self, name, manager="", phone="", parent_id=0):
        sysOrgan = SysOrgan(
            name=name, 
            manager=manager,
            phone=phone,
            parent_id=parent_id
        )
        self.db.add(sysOrgan)
        self.db.commit()
        self.db.refresh(sysOrgan)
        return sysOrgan

    def update_data(self,id, name, manager="", phone="", parent_id=0):
        self.db.query(SysOrgan).filter(SysOrgan.id == id).update({
            SysOrgan.name : name, 
            SysOrgan.manager : manager,
            SysOrgan.phone : phone,
            SysOrgan.parent_id : parent_id
        })
        self.db.commit()

    def get_data_by_name(self, name):
        return self.db.query(SysOrgan).filter(SysOrgan.name == name).first()
    
    def get_data_by_nameAndParent(self, name,parentId):
        return self.db.query(SysOrgan).filter(SysOrgan.parent_id == parentId,SysOrgan.name == name).first()
    
    def get_data(self, data_id):
        return self.db.query(SysOrgan).filter(SysOrgan.id == data_id).first()

    def get_all_data(self):
        return self.db.query(SysOrgan).all()
    
    def get_all_data_by_parentId(self,parentId):
        return self.db.query(SysOrgan).filter(SysOrgan.parent_id == parentId).all()

    def delete_data(self, data_id):
        sysOrgan = self.get_data(data_id)
        if sysOrgan:
            self.db.delete(sysOrgan)
            self.db.commit()

class SysUserRoleOrganBusiness:
    def __init__(self, db):
        self.db = db

    def get_last_use_SURO(self,userId):
        return self.db.query(SysUserRoleOrgan).filter(SysUserRoleOrgan.user_id == userId).order_by(SysUserRoleOrgan.last_use_time.desc()).first()
    
    def getSUROById(self,id):
        return self.db.query(SysUserRoleOrgan).filter(SysUserRoleOrgan.id == id).first()
    

    def get_SURO(self,user_id, organ_id):
        return self.db.query(SysUserRoleOrgan).filter(SysUserRoleOrgan.user_id == user_id,SysUserRoleOrgan.organ_id == organ_id).first()
    
    def insert_data(self, user_id, role_id, organ_id, data_type,create_by):
        sysUserRoleOrgan = SysUserRoleOrgan(
            user_id=user_id, 
            role_id=role_id,
            organ_id=organ_id,
            data_type=data_type,
            create_time=datetime.now(),
            create_by=create_by
        )
        self.db.add(sysUserRoleOrgan)
        self.db.commit()
        self.db.refresh(sysUserRoleOrgan)
        return sysUserRoleOrgan
    
    def update_data(self,id, user_id, role_id, organ_id, data_type,update_by):
        self.db.query(SysUserRoleOrgan).filter(SysUserRoleOrgan.id == id).update({
            SysUserRoleOrgan.user_id : user_id, 
            SysUserRoleOrgan.role_id : role_id,
            SysUserRoleOrgan.organ_id : organ_id,
            SysUserRoleOrgan.data_type : data_type,
            SysUserRoleOrgan.update_time : datetime.now(),
            SysUserRoleOrgan.update_by : update_by
        })
        self.db.commit()

    def updateLastUseTime(self,id):
        self.db.query(SysUserRoleOrgan).filter(SysUserRoleOrgan.id == id).update({
            SysUserRoleOrgan.last_use_time : datetime.now()
        })
        self.db.commit()

    def delete_data(self, data_id):
        sysUserRoleOrgan = self.getSUROById(data_id)
        if sysUserRoleOrgan:
            self.db.delete(sysUserRoleOrgan)
            self.db.commit()
